#include "kmp.h"

/* Returns the flags for the schedule and chunking type for Aftermath for a
 * schedule type defined by the run-time.
 */
static inline am_omp_for_flags_t
kmpt_for_schedule_to_flags(enum sched_type schedtype)
{
	switch(SCHEDULE_WITHOUT_MODIFIERS(schedtype)) {
		case kmp_sch_static_chunked:
		case kmp_ord_static_chunked:
		case kmp_nm_static_chunked:
		case kmp_nm_ord_static_chunked:
			return OMP_FOR_SCHEDULE_STATIC |
				OMP_FOR_CHUNKED;

		case kmp_sch_static:
		case kmp_sch_static_greedy:
		case kmp_sch_static_balanced:
		case kmp_sch_static_steal:
		case kmp_ord_static:
		case kmp_nm_static:
		case kmp_nm_static_greedy:
		case kmp_nm_static_balanced:
		case kmp_nm_static_steal:
		case kmp_nm_ord_static:
			return OMP_FOR_SCHEDULE_STATIC;

		case kmp_sch_dynamic_chunked:
		case kmp_ord_dynamic_chunked:
		case kmp_nm_dynamic_chunked:
		case kmp_nm_ord_dynamic_chunked:
			return OMP_FOR_SCHEDULE_DYNAMIC |
				OMP_FOR_CHUNKED;

		case kmp_sch_guided_chunked:
		case kmp_sch_guided_iterative_chunked:
		case kmp_sch_guided_analytical_chunked:
		case kmp_ord_guided_chunked:
		case kmp_nm_guided_chunked:
		case kmp_nm_guided_iterative_chunked:
		case kmp_nm_guided_analytical_chunked:
		case kmp_nm_ord_guided_chunked:
			return OMP_FOR_SCHEDULE_GUIDED;

#if OMP_40_ENABLED
		case kmp_distribute_static_chunked:
			return OMP_FOR_SCHEDULE_STATIC |
				OMP_FOR_CHUNKED;

		case kmp_distribute_static:
			return OMP_FOR_SCHEDULE_STATIC;
#endif
	}
}
